'use strict';

/* jshint quotmark: double */
window.SwaggerTranslator.learn({
    "Warning: Deprecated":"Προειδοποίηση: Έχει αποσυρθεί",
    "Implementation Notes":"Σημειώσεις Υλοποίησης",
    "Response Class":"Απόκριση",
    "Status":"Κατάσταση",
    "Parameters":"Παράμετροι",
    "Parameter":"Παράμετρος",
    "Value":"Τιμή",
    "Description":"Περιγραφή",
    "Parameter Type":"Τύπος Παραμέτρου",
    "Data Type":"Τύπος Δεδομένων",
    "Response Messages":"Μηνύματα Απόκρισης",
    "HTTP Status Code":"Κωδικός Κατάστασης HTTP",
    "Reason":"Αιτιολογία",
    "Response Model":"Μοντέλο Απόκρισης",
    "Request URL":"URL Αιτήματος",
    "Response Body":"Σώμα Απόκρισης",
    "Response Code":"Κωδικός Απόκρισης",
    "Response Headers":"Επικεφαλίδες Απόκρισης",
    "Hide Response":"Απόκρυψη Απόκρισης",
    "Headers":"Επικεφαλίδες",
    "Try it out!":"Δοκιμάστε το!",
    "Show/Hide":"Εμφάνιση/Απόκρυψη",
    "List Operations":"Λίστα Λειτουργιών",
    "Expand Operations":"Ανάπτυξη Λειτουργιών",
    "Raw":"Ακατέργαστο",
    "can't parse JSON.  Raw result":"αδυναμία ανάλυσης JSON.  Ακατέργαστο αποτέλεσμα",
    "Example Value":"Παράδειγμα Τιμής",
    "Model Schema":"Σχήμα Μοντέλου",
    "Model":"Μοντέλο",
    "Click to set as parameter value":"Πατήστε για να θέσετε τιμή παραμέτρου",
    "apply":"εφαρμογή",
    "Username":"Όνομα χρήση",
    "Password":"Κωδικός πρόσβασης",
    "Terms of service":"Όροι χρήσης",
    "Created by":"Δημιουργήθηκε από",
    "See more at":"Δείτε περισσότερα στο",
    "Contact the developer":"Επικοινωνήστε με τον προγραμματιστή",
    "api version":"έκδοση api",
    "Response Content Type":"Τύπος Περιεχομένου Απόκρισης",
    "Parameter content type:":"Τύπος περιεχομένου παραμέτρου:",
    "fetching resource":"παραλαβή πόρου",
    "fetching resource list":"παραλαβή λίστας πόρων",
    "Explore":"Εξερεύνηση",
    "Show Swagger Petstore Example Apis":"Εμφάνιση Api Δειγμάτων Petstore του Swagger",
    "Can't read from server.  It may not have the appropriate access-control-origin settings.":"Αδυναμία ανάγνωσης από τον εξυπηρετητή.  Μπορεί να μην έχει κατάλληλες ρυθμίσεις για access-control-origin.",
    "Please specify the protocol for":"Παρακαλώ προσδιορίστε το πρωτόκολλο για",
    "Can't read swagger JSON from":"Αδυναμία ανάγνωσης swagger JSON από",
    "Finished Loading Resource Information. Rendering Swagger UI":"Ολοκλήρωση Φόρτωσης Πληροφορικών Πόρου. Παρουσίαση Swagger UI",
    "Unable to read api":"Αδυναμία ανάγνωσης api",
    "from path":"από το μονοπάτι",
    "server returned":"ο εξυπηρετηρής επέστρεψε"
});
